<?php
/**
 * Enqueue styles and scripts
 */
add_action('admin_enqueue_scripts','nikan_faqp_admin_css_js');
function nikan_faqp_admin_css_js(){
    $textarea_type_is_wordpress = 'false';
    if (get_option('nikan_faqp_textarea_type') === 'wordpress'){
        $textarea_type_is_wordpress = 'true';
    }
    wp_enqueue_editor();
    wp_enqueue_media();
    wp_enqueue_style('nikan_faqp-adminstyle', plugins_url('assets/css/admin_faqp.css', dirname(__FILE__)));
    wp_enqueue_script('nikan_faqp-adminscript', plugins_url('assets/js/admin_nikan_faqp.js', dirname(__FILE__)));
    wp_localize_script('nikan_faqp-adminscript', 'nikan_faqp_object', array(
        'question_label' => esc_html__('Question', 'faq-plus'),
        'question_input' => esc_html__('Question', 'faq-plus'),
        'answer_input' => esc_html__('Answer', 'faq-plus'),
        'remove_row_error' => esc_html__('You must have at least one question', 'faq-plus'),
        'textarea_type_wordpress' => $textarea_type_is_wordpress
    ));
}

/**
 * Making Custom Meta Box
 */
function nikan_faqp_add_meta_box(){
    add_meta_box(
        'nikan_faqp_meta_box_content_id',
        __('FAQ Question and Answer', 'faq-plus'),
        'nikan_faqp_meta_box_content',
        'faqp'
    );
    $questions =  get_post_meta( get_the_ID(), 'nikan_faqp_question', true );
    $answers = get_post_meta( get_the_ID(), 'nikan_faqp_answer', true );
    if (!empty($answers) and !empty($questions)) {
        add_meta_box(
            'nikan_faqp_meta_box_shortcode',
            __('FAQ Shortcode', 'faq-plus'),
            'nikan_faqp_meta_box_shortcode',
            'faqp',
            'side',
            'low'
        );
    }
}
add_action( 'add_meta_boxes', 'nikan_faqp_add_meta_box' );

/**
 * Display Textarea Based on Settings
 * @param $content = content of Must be in textarea
 * @param $id = the id Of textarea
 */
function nikan_faqp_textarea($content, $id = ''){
    $get_textarea_type = get_option('nikan_faqp_textarea_type');
    if ($get_textarea_type === 'wordpress'){
        wp_editor($content, $id = 'content'.$id, array('textarea_name' => 'nikan_faqp_answer[]'));
    }else{
        ?>
        <textarea class="form-control" type="text" name="nikan_faqp_answer[]"
                  placeholder="<?php esc_html_e('Answer', 'faq-plus'); ?>" rows="4" cols="50"
                  required><?php echo $content ?></textarea>
        <?php
    }
}

/**
 * FAQ Meta Box Content
 * @param $post
 */
function nikan_faqp_meta_box_content( $post ){
    $faqps = array();
    $questions =  get_post_meta( $post->ID, 'nikan_faqp_question', true );
    $answers = get_post_meta( $post->ID, 'nikan_faqp_answer', true );
    $display_type = get_post_meta( $post->ID, 'faqp_display_type', true );
    $template_type = get_option('faqp_template_type');
    if (!empty($answers) and !empty($questions)) {
        $faqps = array_combine($questions, $answers);
    } ?>
    <div class="nikan_faqp_faqp_display_type">
        <h5><?php esc_html_e('Select FAQ Type', 'faq-plus'); ?></h5>
        <div>
            <input type="radio" name="faqp_display_type" id="accordion" value="accordion" <?php if ($display_type === 'accordion' or !$display_type) echo 'checked'?> required>
            <label for="accordion"><?php esc_html_e('Accordion', 'faq-plus'); ?></label><br><br>
            <input type="radio" name="faqp_display_type" id="simple" value="simple" <?php if ($display_type === 'simple') echo 'checked'?> required>
            <label for="simple"><?php esc_html_e('Simple', 'faq-plus'); ?></label><br><br>
        </div>
    </div>
    <div class="nikan_faqps nikan_faqp_dropme">
        <?php
        if (!empty($faqps)) {
            $i = 0;
            foreach ($faqps as $question => $answer) {
                $i++;
                ?>
                <div class="nikan_faqp_row">
                    <div class="nikan_faqp_remove_row">
                        <a href="#">
                            <i class="dashicons dashicons-dismiss"></i>
                        </a>
                    </div>
                    <a class="nikan_faqp_accordion"><?php echo $question ?> </a>
                    <button class="nikan_faqp_open_row"><i></i></button>
                    <div class="nikan_faqp_form_row">
                        <div class="d-flex nikan_faqp_question_input">
                            <label for="nikan_faqp_question">
                                <?php esc_html_e('Question', 'faq-plus'); ?>
                            </label>
                            <input class="form-control" value="<?php echo $question ?>" type="text"
                                   name="nikan_faqp_question[]"
                                   placeholder="<?php esc_html_e('Question', 'faq-plus'); ?>" required>
                        </div>
                        <div class="d-flex nikan_faqp_answer_input">
                            <label for="nikan_faqp_answer">
                                <?php esc_html_e('Answer', 'faq-plus'); ?>
                            </label>
                            <?php nikan_faqp_textarea($answer,$i); ?>
                        </div>
                    </div>
                </div>
                <?php
            }
        } else { ?>
            <div class="nikan_faqp_row">
                <div class="nikan_faqp_remove_row">
                    <a href="#">
                        <i class="dashicons dashicons-dismiss"></i>
                    </a>
                </div>
                <a class="nikan_faqp_accordion"><?php esc_html_e('Question', 'faq-plus'); ?> </a>
                <button class="nikan_faqp_open_row"><i></i></button>
                <div class="nikan_faqp_form_row">
                    <div class="d-flex nikan_faqp_question_input">
                        <label for="nikan_faqp_question">
                            <?php esc_html_e('Question', 'faq-plus'); ?>
                        </label>
                        <input class="form-control" type="text" name="nikan_faqp_question[]"
                               placeholder="<?php esc_html_e('Question', 'faq-plus'); ?>" required>
                    </div>
                    <div class="d-flex nikan_faqp_answer_input">
                        <label for="nikan_faqp_answer">
                            <?php esc_html_e('Answer', 'faq-plus'); ?>
                        </label>
                        <?php nikan_faqp_textarea(''); ?>
                    </div>
                </div>
            </div>
        <?php }
        ?>
    </div>
    <div class="nikan_faqp_table_add_row">
        <button type="submit" name="nikan_faqp_submit_form" class="button button-primary button-large add-row">
            <?php esc_html_e('Add New', 'faq-plus');?>
        </button>
    </div>
    <?php
}

/**
 * FAQ Meta Box Save
 * @param $post_id
 */
function nikan_faqp_save_postdata( $post_id ) {
    if ( array_key_exists( 'nikan_faqp_question', $_POST ) and array_key_exists( 'nikan_faqp_answer', $_POST ) and array_key_exists( 'faqp_display_type', $_POST )) {
        update_post_meta(
            $post_id,
            'nikan_faqp_question',
            array_map( 'sanitize_text_field', wp_unslash( $_POST['nikan_faqp_question'] ) )
        );
        update_post_meta(
            $post_id,
            'nikan_faqp_answer',
            array_map( 'wp_kses_post', wp_unslash( $_POST['nikan_faqp_answer'] ) )
        );
        update_post_meta(
            $post_id,
            'faqp_display_type',
            sanitize_text_field( $_POST['faqp_display_type'] )
        );
    }
}
add_action( 'save_post', 'nikan_faqp_save_postdata' );

/**
 * Faq Meta Box Shortcode
 * @param $post
 */
function nikan_faqp_meta_box_shortcode( $post ){
    $questions =  get_post_meta( $post->ID, 'nikan_faqp_question', true );
    $answers = get_post_meta( $post->ID, 'nikan_faqp_answer', true );
    if (!empty($answers) and !empty($questions)) { ?>
        <div class="nikan_faqp_shortcode_box">
        <code>
            [faqp id=<?php echo $post->ID?>]
        </code>
    </div>
    <?php }
}

/**
 * Display FAQ Based On Shortcode
 * @param $atts = Shortcode Attr
 */
function nikan_faqp_shortcode( $atts ) {
    $atts = shortcode_atts(array('id' => get_the_ID()), $atts, 'faqp');
    $questions =  get_post_meta( $atts['id'], 'nikan_faqp_question', true );
    $answers = get_post_meta( $atts['id'], 'nikan_faqp_answer', true );
    $display_type = get_post_meta( $atts['id'], 'faqp_display_type', true );
    $template_type = get_option('faqp_template_type');
    $collapse_count = 0;
    if (!empty($answers) and !empty($questions)) {
        $faqps = array_combine($questions, $answers);
        if ($display_type === 'accordion' or !$display_type) : ?>
            <div class="<?php echo ($template_type === 'bootstrap') ? 'col-12' : 'nikan_faqp_w_100'?>" itemscope itemtype="https://schema.org/FAQPage">
                <?php foreach ($faqps as $question => $answer) : $collapse_count++;?>
                    <?php if ($template_type === 'bootstrap') {
                        add_action('wp_footer', function () {
                            if (!wp_script_is('jquery', 'enqueued')) : wp_enqueue_script('jquery'); endif;
                            wp_enqueue_style('nikan_faqp-bootstrap-style', plugins_url('assets/css/bootstrap.min.css', dirname(__FILE__)));
                            wp_enqueue_script('nikan_faqp-bootstrap-script', plugins_url('assets/js/bootstrap.min.js', dirname(__FILE__)));
                        });
                        ?>
                        <div class="card" itemscope itemprop="mainEntity" itemtype="https://schema.org/Question">
                            <div class="card-header">
                                <h5 class="mb-0 mt-0">
                                    <button itemprop="name" class="faqp-btn faqp-btn-link" data-toggle="collapse"
                                            data-target="#collapse<?php echo $collapse_count;?>" aria-expanded="true" aria-controls="collapse<?php echo $collapse_count;?>">
                                        <?php echo $question ?>
                                    </button>
                                </h5>
                            </div>

                            <div id="collapse<?php echo $collapse_count;?>" class="collapse" itemscope itemprop="acceptedAnswer" itemtype="https://schema.org/Answer">
                                <div class="card-body" itemprop="text">
                                    <?php echo $answer ?>
                                </div>
                            </div>
                        </div>
                    <?php } else { ?>
                        <?php add_action('wp_footer', function () {
                            if (!wp_script_is('jquery', 'enqueued')) : wp_enqueue_script('jquery'); endif;
                            wp_enqueue_style('nikan_faqp-adminstyle', plugins_url('assets/css/front_nikan_faqp.css', dirname(__FILE__)));
                            wp_enqueue_script('nikan_faqp-adminscript', plugins_url('assets/js/front_nikan_faqp.js', dirname(__FILE__)));
                        }); ?>
                        <div class="nikan_faqp_front_inner" itemscope itemprop="mainEntity" itemtype="https://schema.org/Question">
                            <div class="nikan_faqp_front_question" itemprop="name">
                                <?php echo $question ?>
                                <button class="nikan_faqp_open_row"><i></i></button>
                            </div>
                            <div class="nikan_faqp_front_answer" itemscope itemprop="acceptedAnswer" itemtype="https://schema.org/Answer">
                                <div itemprop="text">
                                    <?php echo $answer ?>
                                </div>
                            </div>
                        </div>
                    <?php } ?>
                <?php endforeach; ?>
            </div>
        <?php else : ?>
            <?php add_action('wp_footer', function () {
                wp_enqueue_style('nikan_faqp-adminstyle', plugins_url('assets/css/front_nikan_faqp.css', dirname(__FILE__)));
            }); ?>
            <div itemscope itemtype="https://schema.org/FAQPage">
                <?php foreach ($faqps as $question => $answer) : ?>
                    <div class="nikan_faqp_front_inner" itemscope itemprop="mainEntity" itemtype="https://schema.org/Question">
                        <h2 class="nikan_faqp_front_question"  itemprop="name">
                            <?php echo $question ?>
                        </h2>
                        <div class="nikan_faqp_front_simple" itemscope itemprop="acceptedAnswer" itemtype="https://schema.org/Answer">
                            <div  itemprop="text">
                                <?php echo $answer ?>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
        <?php endif;
    }
}
add_shortcode('faqp', 'nikan_faqp_shortcode');

